@@ -8,10 +8,12 @@
 CONSUMER_CONFIG = {}
 PRODUCER_CONFIG = {}
 METRICS_CONFIG = {}
+PROMETHEUS = False
 
 ## Step Configuration
 STEP_CONFIG = {
     "CONSUMER_CONFIG": CONSUMER_CONFIG,
     "PRODUCER_CONFIG": PRODUCER_CONFIG,
     "METRICS_CONFIG": METRICS_CONFIG,
+    "PROMETHEUS": PROMETHEUS,
 }
