@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 import logging
+from typing import Union
 
 
 class GenericProducer(ABC):
@@ -9,6 +10,14 @@ class GenericProducer(ABC):
         self.logger = logging.getLogger(self.__class__.__name__)
         self.logger.info(f"Creating {self.__class__.__name__}")
         self.config = config
+        self._key_field = None
+
+    @property
+    def key_field(self):
+        return self._key_field
+
+    def set_key_field(self, key):
+        self._key_field = key
 
     @abstractmethod
     def produce(self, message=None, **kwargs):
